@@ -40,12 +40,15 @@ class Dino(object):
         msg = self.model.load_state_dict(self.state_dict, strict=False)
         print('Pretrained weights found at {} and loaded with msg: {}'.format(pretrained_weights, msg))
     
-    def encode(self, image_paths):
+    def encode(self, image_paths, src_type="local"):
         imgs = []
         for image_path in image_paths:
-            with open(image_path, 'rb') as f:
-                img = Image.open(f)
-                img = img.convert('RGB')
+            if src_type == "local":
+                with open(image_path, 'rb') as f:
+                    img = Image.open(f)
+                    img = img.convert('RGB')
+            else:
+                img = image_path
             transform = pth_transforms.Compose([
                 pth_transforms.Resize(self.image_size),
                 pth_transforms.ToTensor(),
