@@ -23,12 +23,12 @@ class ImageClassification(object):
         for _imgs in chunk_list(images):     
             with torch.no_grad():
                 temp = []
-                if x in _img:
+                for x in _imgs:
                     if type(x) == str:
                         temp.append(self.transform(Image.open(x).convert('RGB')).to(self.device))
                     else:
                         temp.append(self.transform(x).to(self.device))
-                preicts = self.model(torch.stack(temp))
+                predicts = self.model(torch.stack(temp))
                 #predicts = self.model(torch.stack([self.transform(Image.open(x).convert('RGB')).to(self.device) for x in _imgs]))
                 predicts = torch.nn.functional.softmax(predicts).max(1)            
             results.extend([{"pred": self.labels[x], "score":y} for x,y in zip(predicts.indices.cpu().numpy().tolist(),predicts.values.cpu().numpy().tolist())])
